menu
hypersnapsdk_flutter package
documentation
hv_face_capture.dart
hv_face_capture.dart
dark_mode
light_mode
hv_face_capture
library
Classes
HVFaceCapture
Class that provides face capture functionality.
HVFaceCapturePadding
Represents the padding values for face capture.
HVFaceCaptureUIStrings
HVFaceCaptureUIStrings is used to set custom strings for all customizable text in HyperSnapSDK face capture.
HVFaceConfig
HVFaceConfig is used to customise HyperSnapSDK face capture flow.
HVLivenessAPIDetails
HVLivenessAPIDetails is used to pre-set the endpoint, liveness value, params, and headers for making a liveness API call immediately after the document has been captured.
HVVideoRecordingConfig
Configuration for video recording in the user's selfie flow.
Enums
LivenessMode
Enum representing different liveness modes.
VideoRecordingMode
Enum representing different video recording modes.
Extensions
LivenessModeExtension
on
LivenessMode
Extension methods for the
LivenessMode
enum.
VideoRecordingModeExtension
on
VideoRecordingMode
Extension methods for the
VideoRecordingMode
enum.
hypersnapsdk_flutter package
documentation
hv_face_capture.dart
hypersnapsdk_flutter
package
Libraries
hv_barcode_capture
hv_docs_capture
hv_face_capture
hv_network_helper
hv_result
hv_ui_config
hyper_snap_sdk
hyper_snap_sdk_constants
hypersnapsdk_flutter
hv_face_capture library